Struct clocked::StreamSource

source ·
pub struct StreamSource {
    pub xruns: usize,
    /* private fields */
}

Fields

xruns: usize

# of xruns

Implementations

source

impl StreamSource

source

pub fn new( ring_out: Producer<f32>, channels: usize, compensation_start_threshold: usize, pid_settings: PidSettings ) -> StreamSource

Creates a stream source.

  • ring_out - the Producer half of a rtrb ring buffer (interleaved)
  • channels - the number of channels
  • compensation_start_threshold - the number of xruns
  • startup_time - how long to wait before measuring xruns
  • pid_settings - various PID settings
source

pub fn with_defaults(ring_out: Producer<f32>, channels: usize) -> StreamSource

Creates a stream source with defaults (see StreamSource::new).

  • ring_out - the Producer half of a rtrb ring buffer (interleaved)
  • channels - the number of channels
source

pub fn channels(&self) -> usize

source

pub fn get_strategy(&self) -> &CompensationStrategy

See what strategy is currently being used.

source

pub fn input_samples( &mut self, buffer_in: impl IntoIterator<Item = f32>, buffer_len: usize, measure_xruns: bool )

source

pub fn enable_compensation(&mut self)

Forces compensation to start

source

pub fn disable_compensation(&mut self)

Forces compensation to never happen

source

pub fn auto_compensation(&mut self)

Resets mode to auto (default mode)